@@ -16,7 +16,10 @@ def create_shell(arguments: typing.List[str] = None) -> "interactivity.Shell":
     """
     args = parsing.create_parser(True).parse_args(arguments)
     directory = pathlib.Path(args.root_directory).absolute()
-    session = boto3.Session(profile_name=args.aws_profile_name)
+    session = boto3.Session(
+        profile_name=args.aws_profile_name,
+        region_name=args.aws_region_name,
+    )
     context = definitions.Context.load_from_file(
         arguments=args,
         path=directory,
@@ -37,3 +40,8 @@ def run_shell(
     shell.command_queue += command_queue or shell.context.command_queue or []
     shell.run()
     return shell
+
+
+def main_shell() -> None:  # pragma: no cover
+    """Main entrypoint for the local shell cli."""
+    run_shell()
