@@ -184,6 +184,9 @@ class Shell:
                 error=error,
                 message="An unexpected command error occurred.",
             )
+            if not self.is_interactive:
+                # Raise the error when running in non-interactive mode.
+                raise
 
         self._teardown()
 
@@ -203,9 +206,11 @@ class Shell:
         without a prompt instead.
         """
         context = self.context
+        configuration = context.configuration
         templating.printer(
             "interactivity/shells/prompt.jinja2",
             profile=context.connection.session.profile_name or "default",
+            region=configuration.aws_region,
             user_slug=context.connection.user_slug,
             selected=context.get_selected_targets(self.selection),
         )
